summaryrefslogtreecommitdiff
path: root/src/lib/player.h
diff options
context:
space:
mode:
authorCarl Hetherington <cth@carlh.net>2017-04-09 22:43:56 +0100
committerCarl Hetherington <cth@carlh.net>2017-04-19 23:04:32 +0100
commit4073923b2c5ccf127c61435cd575542351421f05 (patch)
tree15c5708ba2e8f6dc64a5d843aca3549132938e93 /src/lib/player.h
parentad0c51a63b40922c900ccc03c3b6417874a8c981 (diff)
Several fixes to audio.
Diffstat (limited to 'src/lib/player.h')
-rw-r--r--src/lib/player.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/lib/player.h b/src/lib/player.h
index 6e9c9d7ee..ea07e1fc8 100644
--- a/src/lib/player.h
+++ b/src/lib/player.h
@@ -139,11 +139,11 @@ private:
/** Last PlayerVideo that was emitted */
boost::shared_ptr<PlayerVideo> _last_video;
- /** Time of the last thing we emitted, or the last seek time */
- boost::optional<DCPTime> _last_time;
+ /** Time of the last video we emitted, or the last seek time */
+ boost::optional<DCPTime> _last_video_time;
AudioMerger _audio_merger;
- DCPTime _last_audio_time;
+ boost::optional<DCPTime> _last_audio_time;
class StreamState {
public: